.. gcm-filters documentation master file, created by
   sphinx-quickstart on Tue Jan 12 09:24:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to seaflux's documentation!
=======================================

SeaFlux is a Python 3.6+ package that can be used to calculate air-sea CO2 fluxes for the global ocean.
The SeaFlux Python package is a companion package to the SeaFlux dataset that is under review in
ESSD discussions (https://doi.org/10.5194/essd-2021-16).

SeaFlux provides high level code to access the datasets presented in the ESSD manuscript.
Further, the package provides the code to calculate these data sets.

Installation
------------

.. code-block:: bash

   # for latest release
   pip install seaflux

   # for bleeding-edge up-to-date commit
   pip install -e git+https://github.com/lukegre/SeaFlux.git




.. toctree::
   :maxdepth: 3
   :caption: Contents

   data_product
   api


.. toctree::
   :maxdepth: 2
   :caption: Help and Reference

   contributing
   authors
   GitHub Repo <https://github.com/lukegre/SeaFlux>


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
